@@ -2,13 +2,14 @@ import sys
 from datetime import datetime
 from multiprocessing import cpu_count
 
-from twisted.internet import reactor, defer, protocol, error
 from twisted.application.service import Service
+from twisted.internet import defer, error, protocol, reactor
 from twisted.python import log
 
-from scrapyd.utils import get_crawl_args, native_stringify_dict
 from scrapyd import __version__
-from .interfaces import IPoller, IEnvironment, IJobStorage
+from scrapyd.interfaces import IEnvironment, IJobStorage, IPoller
+from scrapyd.utils import get_crawl_args, native_stringify_dict
+
 
 class Launcher(Service):
 
@@ -20,7 +21,6 @@ class Launcher(Service):
         self.max_proc = self._get_max_proc(config)
         self.runner = config.get('runner', 'scrapyd.runner')
         self.app = app
-        
 
     def startService(self):
         for slot in range(self.max_proc):
@@ -34,15 +34,17 @@ class Launcher(Service):
         poller.next().addCallback(self._spawn_process, slot)
 
     def _spawn_process(self, message, slot):
+        e = self.app.getComponent(IEnvironment)
+        message.setdefault('settings', {})
+        message['settings'].update(e.get_settings(message))
         msg = native_stringify_dict(message, keys_only=False)
         project = msg['_project']
         args = [sys.executable, '-m', self.runner, 'crawl']
         args += get_crawl_args(msg)
-        e = self.app.getComponent(IEnvironment)
         env = e.get_environment(msg, slot)
         env = native_stringify_dict(env, keys_only=False)
-        pp = ScrapyProcessProtocol(slot, project, msg['_spider'], \
-            msg['_job'], env)
+        pp = ScrapyProcessProtocol(slot, project, msg['_spider'],
+                                   msg['_job'], env)
         pp.deferred.addBoth(self._process_finished, slot)
         reactor.spawnProcess(pp, sys.executable, args=args, env=env)
         self.processes[slot] = pp
@@ -63,6 +65,7 @@ class Launcher(Service):
             max_proc = cpus * config.getint('max_proc_per_cpu', 4)
         return max_proc
 
+
 class ScrapyProcessProtocol(protocol.ProcessProtocol):
 
     def __init__(self, slot, project, spider, job, env):
@@ -74,8 +77,8 @@ class ScrapyProcessProtocol(protocol.ProcessProtocol):
         self.start_time = datetime.now()
         self.end_time = None
         self.env = env
-        self.logfile = env.get('SCRAPY_LOG_FILE')
-        self.itemsfile = env.get('SCRAPY_FEED_URI')
+        self.logfile = env.get('SCRAPYD_LOG_FILE')
+        self.itemsfile = env.get('SCRAPYD_FEED_URI')
         self.deferred = defer.Deferred()
 
     def outReceived(self, data):
